package java.text;

import java.util.AbstractMap;
import java.util.Hashtable;
import java.util.Set;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Vector;

public class AttributedString
{
    private static final int ARRAY_SIZE_INCREMENT = 10;
    String text;
    int runArraySize;
    int runCount;
    int[] runStarts;
    Vector<AttributedCharacterIterator.Attribute>[] runAttributes;
    Vector<Object>[] runAttributeValues;
    
    AttributedString(AttributedCharacterIterator[] array) {
        if (array == null) {
            throw new NullPointerException("Iterators must not be null");
        }
        if (array.length == 0) {
            this.text = "";
        }
        else {
            StringBuffer sb = new StringBuffer();
            for (int i = 0; i < array.length; ++i) {
                this.appendContents(sb, array[i]);
            }
            this.text = sb.toString();
            if (this.text.length() > 0) {
                int n = 0;
                Map<Object, Object> map = null;
                int k;
                int endIndex;
                for (int j = 0; j < array.length; n += endIndex - k, ++j) {
                    AttributedCharacterIterator attributedCharacterIterator;
                    Map<AttributedCharacterIterator.Attribute, Object> attributes;
                    for (attributedCharacterIterator = array[j], k = attributedCharacterIterator.getBeginIndex(), endIndex = attributedCharacterIterator.getEndIndex(), ; k < endIndex; map = attributes, k = attributedCharacterIterator.getRunLimit()) {
                        attributedCharacterIterator.setIndex(k);
                        attributes = attributedCharacterIterator.getAttributes();
                        if (mapsDiffer(map, attributes)) {
                            this.setAttributes(attributes, k - k + n);
                        }
                    }
                }
            }
        }
        return;
    }
    
    public AttributedString(String text) {
        if (text == null) {
            throw new NullPointerException();
        }
        this.text = text;
        return;
    }
    
    public AttributedString(String text, Map<? extends AttributedCharacterIterator.Attribute, ?> map) {
        if (text == null || map == null) {
            throw new NullPointerException();
        }
        this.text = text;
        if (text.length() == 0) {
            if (map.isEmpty()) {
                return;
            }
            throw new IllegalArgumentException("Can't add attribute to 0-length text");
        }
        else {
            int size = map.size();
            if (size > 0) {
                this.createRunAttributeDataVectors();
                Vector vector = new Vector(size);
                Vector vector2 = new Vector(size);
                this.runAttributes[0] = vector;
                this.runAttributeValues[0] = vector2;
                for (Map.Entry entry : map.entrySet()) {
                    vector.addElement(entry.getKey());
                    vector2.addElement(entry.getValue());
                }
            }
            return;
        }
    }
    
    public AttributedString(AttributedCharacterIterator attributedCharacterIterator) {
        this(attributedCharacterIterator, attributedCharacterIterator.getBeginIndex(), attributedCharacterIterator.getEndIndex(), (AttributedCharacterIterator$Attribute[])null);
    }
    
    public AttributedString(AttributedCharacterIterator attributedCharacterIterator, int n, int n2) {
        this(attributedCharacterIterator, n, n2, (AttributedCharacterIterator$Attribute[])null);
    }
    
    public AttributedString(AttributedCharacterIterator attributedCharacterIterator, int index, int n, AttributedCharacterIterator.Attribute[] array) {
        if (attributedCharacterIterator == null) {
            throw new NullPointerException();
        }
        int beginIndex = attributedCharacterIterator.getBeginIndex();
        int endIndex = attributedCharacterIterator.getEndIndex();
        if (index < beginIndex || n > endIndex || index > n) {
            throw new IllegalArgumentException("Invalid substring range");
        }
        StringBuffer sb = new StringBuffer();
        attributedCharacterIterator.setIndex(index);
        int c = attributedCharacterIterator.current();
        while (attributedCharacterIterator.getIndex() < n) {
            sb.append((char)c);
            c = attributedCharacterIterator.next();
        }
        this.text = sb.toString();
        if (index == n) {
            return;
        }
        HashSet o = new HashSet();
        if (array == null) {
            o.addAll(attributedCharacterIterator.getAllAttributeKeys());
        }
        else {
            for (int i = 0; i < array.length; ++i) {
                o.add(array[i]);
            }
            o.retainAll(attributedCharacterIterator.getAllAttributeKeys());
        }
        if (o.isEmpty()) {
            return;
        }
        for (AttributedCharacterIterator.Attribute attribute : o) {
            attributedCharacterIterator.setIndex(beginIndex);
            while (attributedCharacterIterator.getIndex() < n) {
                int runStart = attributedCharacterIterator.getRunStart(attribute);
                int runLimit = attributedCharacterIterator.getRunLimit(attribute);
                Object attribute2 = attributedCharacterIterator.getAttribute(attribute);
                if (attribute2 != null) {
                    if ((attribute2 instanceof Annotation)) {
                        if (runStart >= index && runLimit <= n) {
                            this.addAttribute(attribute, attribute2, runStart - index, runLimit - index);
                        }
                        else if (runLimit > n) {
                            break;
                        }
                    }
                    else {
                        if (runStart >= n) {
                            break;
                        }
                        if (runLimit > index) {
                            if (runStart < index) {
                                runStart = index;
                            }
                            if (runLimit > n) {
                                runLimit = n;
                            }
                            if (runStart != runLimit) {
                                this.addAttribute(attribute, attribute2, runStart - index, runLimit - index);
                            }
                        }
                    }
                }
                attributedCharacterIterator.setIndex(runLimit);
            }
        }
        return;
    }
    
    public void addAttribute(AttributedCharacterIterator.Attribute attribute, Object o) {
        if (attribute == null) {
            throw new NullPointerException();
        }
        int length = this.length();
        if (length == 0) {
            throw new IllegalArgumentException("Can't add attribute to 0-length text");
        }
        this.addAttributeImpl(attribute, o, 0, length);
        return;
    }
    
    public void addAttribute(AttributedCharacterIterator.Attribute attribute, Object o, int n, int n2) {
        if (attribute == null) {
            throw new NullPointerException();
        }
        if (n < 0 || n2 > this.length() || n >= n2) {
            throw new IllegalArgumentException("Invalid substring range");
        }
        this.addAttributeImpl(attribute, o, n, n2);
        return;
    }
    
    public void addAttributes(Map<? extends AttributedCharacterIterator.Attribute, ?> map, int n, int n2) {
        if (map == null) {
            throw new NullPointerException();
        }
        if (n < 0 || n2 > this.length() || n > n2) {
            throw new IllegalArgumentException("Invalid substring range");
        }
        if (n == n2) {
            if (map.isEmpty()) {
                return;
            }
            throw new IllegalArgumentException("Can't add attribute to 0-length text");
        }
        else {
            if (this.runCount == 0) {
                this.createRunAttributeDataVectors();
            }
            int ensureRunBreak = this.ensureRunBreak(n);
            int ensureRunBreak2 = this.ensureRunBreak(n2);
            for (Map.Entry entry : map.entrySet()) {
                this.addAttributeRunData((AttributedCharacterIterator.Attribute)entry.getKey(), entry.getValue(), ensureRunBreak, ensureRunBreak2);
            }
            return;
        }
    }
    
    private synchronized void addAttributeImpl(AttributedCharacterIterator.Attribute attribute, Object o, int n, int n2) {
        if (this.runCount == 0) {
            this.createRunAttributeDataVectors();
        }
        this.addAttributeRunData(attribute, o, this.ensureRunBreak(n), this.ensureRunBreak(n2));
    }
    
    private final void createRunAttributeDataVectors() {
        int[] runStarts = new int[10];
        Vector[] runAttributes = (Vector[])new Vector[10];
        Vector[] runAttributeValues = (Vector[])new Vector[10];
        this.runStarts = runStarts;
        this.runAttributes = runAttributes;
        this.runAttributeValues = runAttributeValues;
        this.runArraySize = 10;
        this.runCount = 1;
    }
    
    private final int ensureRunBreak(int n) {
        return this.ensureRunBreak(n, true);
    }
    
    private final int ensureRunBreak(int n, boolean b) {
        if (n == this.length()) {
            return this.runCount;
        }
        int n2;
        for (n2 = 0; n2 < this.runCount && this.runStarts[n2] < n; ++n2) {}
        if (n2 < this.runCount && this.runStarts[n2] == n) {
            return n2;
        }
        if (this.runCount == this.runArraySize) {
            int runArraySize = this.runArraySize + 10;
            int[] runStarts = new int[runArraySize];
            Vector[] runAttributes = (Vector[])new Vector[runArraySize];
            Vector[] runAttributeValues = (Vector[])new Vector[runArraySize];
            for (int i = 0; i < this.runArraySize; ++i) {
                runStarts[i] = this.runStarts[i];
                runAttributes[i] = this.runAttributes[i];
                runAttributeValues[i] = this.runAttributeValues[i];
            }
            this.runStarts = runStarts;
            this.runAttributes = runAttributes;
            this.runAttributeValues = runAttributeValues;
            this.runArraySize = runArraySize;
        }
        Object o = null;
        Object o2 = null;
        if (b) {
            Vector<Object> c = this.runAttributes[n2 - 1];
            Vector<Object> c2 = this.runAttributeValues[n2 - 1];
            if (c != null) {
                o = new Vector(c);
            }
            if (c2 != null) {
                o2 = new Vector(c2);
            }
        }
        ++this.runCount;
        for (int j = this.runCount - 1; j > n2; --j) {
            this.runStarts[j] = this.runStarts[j - 1];
            this.runAttributes[j] = this.runAttributes[j - 1];
            this.runAttributeValues[j] = this.runAttributeValues[j - 1];
        }
        this.runStarts[n2] = n;
        this.runAttributes[n2] = o;
        this.runAttributeValues[n2] = o2;
        return n2;
    }
    
    private void addAttributeRunData(AttributedCharacterIterator.Attribute attribute, Object o, int i, int n) {
        int index;
        Object o2;
        Object o3;
        int size;
        for (; i < n; ++i) {
            index = -1;
            if (this.runAttributes[i] == null) {
                o2 = new Vector();
                o3 = new Vector();
                this.runAttributes[i] = o2;
                this.runAttributeValues[i] = o3;
            }
            else {
                index = this.runAttributes[i].indexOf(attribute);
            }
            if (index == -1) {
                size = this.runAttributes[i].size();
                this.runAttributes[i].addElement(attribute);
                try {
                    this.runAttributeValues[i].addElement(o);
                }
                catch (Exception ex) {
                    this.runAttributes[i].setSize(size);
                    this.runAttributeValues[i].setSize(size);
                }
            }
            else {
                this.runAttributeValues[i].set(index, o);
            }
        }
    }
    
    public AttributedCharacterIterator getIterator() {
        return this.getIterator(null, 0, this.length());
    }
    
    public AttributedCharacterIterator getIterator(AttributedCharacterIterator.Attribute[] array) {
        return this.getIterator(array, 0, this.length());
    }
    
    public AttributedCharacterIterator getIterator(AttributedCharacterIterator.Attribute[] array, int n, int n2) {
        return new AttributedString.AttributedStringIterator(array, n, n2);
    }
    
    int length() {
        return this.text.length();
    }
    
    private char charAt(int index) {
        return this.text.charAt(index);
    }
    
    private synchronized Object getAttribute(AttributedCharacterIterator.Attribute o, int n) {
        Vector<Object> vector = this.runAttributes[n];
        Vector<Object> vector2 = this.runAttributeValues[n];
        if (vector == null) {
            return null;
        }
        int index = vector.indexOf(o);
        if (index != -1) {
            return vector2.elementAt(index);
        }
        return null;
    }
    
    private Object getAttributeCheckRange(AttributedCharacterIterator.Attribute attribute, int n, int n2, int n3) {
        Object attribute2 = this.getAttribute(attribute, n);
        if ((attribute2 instanceof Annotation)) {
            if (n2 > 0) {
                int n4;
                for (, n4 = this.runStarts[n]; n4 >= n2 && valuesMatch(attribute2, this.getAttribute(attribute, n - 1)); --n, n4 = this.runStarts[n]) {}
                if (n4 < n2) {
                    return null;
                }
            }
            int length = this.length();
            if (n3 < length) {
                for (, length = ((n < this.runCount - 1) ? this.runStarts[n + 1] : length); length <= n3 && valuesMatch(attribute2, this.getAttribute(attribute, n + 1)); length = ((++n < this.runCount - 1) ? this.runStarts[n + 1] : length)) {}
                if (length > n3) {
                    return null;
                }
            }
        }
        return attribute2;
    }
    
    private boolean attributeValuesMatch(Set<? extends AttributedCharacterIterator.Attribute> set, int n, int n2) {
        for (AttributedCharacterIterator.Attribute attribute : set) {
            if (!valuesMatch(this.getAttribute(attribute, n), this.getAttribute(attribute, n2))) {
                return false;
            }
            continue;
        }
        return true;
    }
    
    private static final boolean valuesMatch(Object o, Object obj) {
        if (o == null) {
            return obj == null;
        }
        return o.equals(obj);
    }
    
    private final void appendContents(StringBuffer sb, CharacterIterator characterIterator) {
        int i = characterIterator.getBeginIndex();
        while (i < characterIterator.getEndIndex()) {
            characterIterator.setIndex(i++);
            sb.append(characterIterator.current());
        }
    }
    
    private void setAttributes(Map<AttributedCharacterIterator.Attribute, Object> map, int n) {
        if (this.runCount == 0) {
            this.createRunAttributeDataVectors();
        }
        int ensureRunBreak = this.ensureRunBreak(n, false);
        int size;
        if (map != null && (size = map.size()) > 0) {
            Vector<Object> vector = new Vector(size);
            Vector<Object> vector2 = new Vector(size);
            for (Map.Entry entry : map.entrySet()) {
                vector.add(entry.getKey());
                vector2.add(entry.getValue());
            }
            this.runAttributes[ensureRunBreak] = vector;
            this.runAttributeValues[ensureRunBreak] = vector2;
        }
    }
    
    private static <K, V> boolean mapsDiffer(Map<K, V> map, Map<K, V> map2) {
        if (map == null) {
            return map2 != null && map2.size() > 0;
        }
        return !map.equals(map2);
    }
    
    static char access$000(AttributedString attributedString, int n) {
        return attributedString.charAt(n);
    }
    
    static Object access$100(AttributedString attributedString, AttributedCharacterIterator.Attribute attribute, int n) {
        return attributedString.getAttribute(attribute, n);
    }
    
    static boolean access$200(Object o, Object o2) {
        return valuesMatch(o, o2);
    }
    
    static boolean access$300(AttributedString attributedString, Set set, int n, int n2) {
        return attributedString.attributeValuesMatch(set, n, n2);
    }
    
    static Object access$400(AttributedString attributedString, AttributedCharacterIterator.Attribute attribute, int n, int n2, int n3) {
        return attributedString.getAttributeCheckRange(attribute, n, n2, n3);
    }
    
    private final class AttributedStringIterator implements AttributedCharacterIterator
    {
        private int beginIndex;
        private int endIndex;
        private AttributedCharacterIterator.Attribute[] relevantAttributes;
        private int currentIndex;
        private int currentRunIndex;
        private int currentRunStart;
        private int currentRunLimit;
        
        AttributedStringIterator(AttributedCharacterIterator.Attribute[] array, int n, int endIndex) {
            if (n < 0 || n > endIndex || endIndex > AttributedString.this.length()) {
                throw new IllegalArgumentException("Invalid substring range");
            }
            this.beginIndex = n;
            this.endIndex = endIndex;
            this.currentIndex = n;
            this.updateRunInfo();
            if (array != null) {
                this.relevantAttributes = (AttributedCharacterIterator.Attribute[])array.clone();
            }
            return;
        }
        
        @Override
        public boolean equals(Object o) {
            if (this == o) {
                return true;
            }
            if (!(o instanceof AttributedString.AttributedStringIterator)) {
                return false;
            }
            AttributedString.AttributedStringIterator attributedStringIterator = (AttributedString.AttributedStringIterator)o;
            return AttributedString.this == attributedStringIterator.getString() && this.currentIndex == attributedStringIterator.currentIndex && this.beginIndex == attributedStringIterator.beginIndex && this.endIndex == attributedStringIterator.endIndex;
        }
        
        @Override
        public int hashCode() {
            return AttributedString.this.text.hashCode() ^ this.currentIndex ^ this.beginIndex ^ this.endIndex;
        }
        
        @Override
        public Object clone() {
            try {
                return (Object)super.clone();
            }
            catch (CloneNotSupportedException cause) {
                throw new InternalError(cause);
            }
        }
        
        @Override
        public char first() {
            return this.internalSetIndex(this.beginIndex);
        }
        
        @Override
        public char last() {
            if (this.endIndex == this.beginIndex) {
                return this.internalSetIndex(this.endIndex);
            }
            return this.internalSetIndex(this.endIndex - 1);
        }
        
        @Override
        public char current() {
            if (this.currentIndex == this.endIndex) {
                return '\uffff';
            }
            return AttributedString.access$000(AttributedString.this, this.currentIndex);
        }
        
        @Override
        public char next() {
            if (this.currentIndex < this.endIndex) {
                return this.internalSetIndex(this.currentIndex + 1);
            }
            return '\uffff';
        }
        
        @Override
        public char previous() {
            if (this.currentIndex > this.beginIndex) {
                return this.internalSetIndex(this.currentIndex - 1);
            }
            return '\uffff';
        }
        
        @Override
        public char setIndex(int n) {
            if (n < this.beginIndex || n > this.endIndex) {
                throw new IllegalArgumentException("Invalid index");
            }
            return this.internalSetIndex(n);
        }
        
        @Override
        public int getBeginIndex() {
            return this.beginIndex;
        }
        
        @Override
        public int getEndIndex() {
            return this.endIndex;
        }
        
        @Override
        public int getIndex() {
            return this.currentIndex;
        }
        
        @Override
        public int getRunStart() {
            return this.currentRunStart;
        }
        
        @Override
        public int getRunStart(AttributedCharacterIterator.Attribute attribute) {
            if (this.currentRunStart == this.beginIndex || this.currentRunIndex == -1) {
                return this.currentRunStart;
            }
            Object attribute2 = this.getAttribute(attribute);
            int n = this.currentRunStart;
            for (int currentRunIndex = this.currentRunIndex; n > this.beginIndex && AttributedString.access$200(attribute2, AttributedString.access$100(AttributedString.this, attribute, currentRunIndex - 1)); --currentRunIndex, n = AttributedString.this.runStarts[currentRunIndex]) {}
            if (n < this.beginIndex) {
                n = this.beginIndex;
            }
            return n;
        }
        
        @Override
        public int getRunStart(Set<? extends AttributedCharacterIterator.Attribute> set) {
            if (this.currentRunStart == this.beginIndex || this.currentRunIndex == -1) {
                return this.currentRunStart;
            }
            int n = this.currentRunStart;
            for (int currentRunIndex = this.currentRunIndex; n > this.beginIndex && AttributedString.access$300(AttributedString.this, set, this.currentRunIndex, currentRunIndex - 1); --currentRunIndex, n = AttributedString.this.runStarts[currentRunIndex]) {}
            if (n < this.beginIndex) {
                n = this.beginIndex;
            }
            return n;
        }
        
        @Override
        public int getRunLimit() {
            return this.currentRunLimit;
        }
        
        @Override
        public int getRunLimit(AttributedCharacterIterator.Attribute attribute) {
            if (this.currentRunLimit == this.endIndex || this.currentRunIndex == -1) {
                return this.currentRunLimit;
            }
            Object attribute2 = this.getAttribute(attribute);
            int n = this.currentRunLimit;
            for (int currentRunIndex = this.currentRunIndex; n < this.endIndex && AttributedString.access$200(attribute2, AttributedString.access$100(AttributedString.this, attribute, currentRunIndex + 1)); n = ((++currentRunIndex < AttributedString.this.runCount - 1) ? AttributedString.this.runStarts[currentRunIndex + 1] : this.endIndex)) {}
            if (n > this.endIndex) {
                n = this.endIndex;
            }
            return n;
        }
        
        @Override
        public int getRunLimit(Set<? extends AttributedCharacterIterator.Attribute> set) {
            if (this.currentRunLimit == this.endIndex || this.currentRunIndex == -1) {
                return this.currentRunLimit;
            }
            int n = this.currentRunLimit;
            for (int currentRunIndex = this.currentRunIndex; n < this.endIndex && AttributedString.access$300(AttributedString.this, set, this.currentRunIndex, currentRunIndex + 1); n = ((++currentRunIndex < AttributedString.this.runCount - 1) ? AttributedString.this.runStarts[currentRunIndex + 1] : this.endIndex)) {}
            if (n > this.endIndex) {
                n = this.endIndex;
            }
            return n;
        }
        
        @Override
        public Map<AttributedCharacterIterator.Attribute, Object> getAttributes() {
            if (AttributedString.this.runAttributes == null || this.currentRunIndex == -1 || AttributedString.this.runAttributes[this.currentRunIndex] == null) {
                return new Hashtable();
            }
            return new AttributedString.AttributeMap(this.currentRunIndex, this.beginIndex, this.endIndex);
        }
        
        @Override
        public Set<AttributedCharacterIterator.Attribute> getAllAttributeKeys() {
            if (AttributedString.this.runAttributes == null) {
                return new HashSet();
            }
            synchronized (AttributedString.this) {
                HashSet<Object> set = new HashSet();
                for (int i = 0; i < AttributedString.this.runCount; ++i) {
                    if (AttributedString.this.runStarts[i] < this.endIndex && (i == AttributedString.this.runCount - 1 || AttributedString.this.runStarts[i + 1] > this.beginIndex)) {
                        Vector<Object> vector = AttributedString.this.runAttributes[i];
                        if (vector != null) {
                            int size = vector.size();
                            while (size-- > 0) {
                                set.add(vector.get(size));
                            }
                        }
                    }
                }
                return set;
            }
        }
        
        @Override
        public Object getAttribute(AttributedCharacterIterator.Attribute attribute) {
            int currentRunIndex = this.currentRunIndex;
            if (currentRunIndex < 0) {
                return null;
            }
            return AttributedString.access$400(AttributedString.this, attribute, currentRunIndex, this.beginIndex, this.endIndex);
        }
        
        private AttributedString getString() {
            return AttributedString.this;
        }
        
        private char internalSetIndex(int currentIndex) {
            this.currentIndex = currentIndex;
            if (currentIndex < this.currentRunStart || currentIndex >= this.currentRunLimit) {
                this.updateRunInfo();
            }
            if (this.currentIndex == this.endIndex) {
                return '\uffff';
            }
            return AttributedString.access$000(AttributedString.this, currentIndex);
        }
        
        private void updateRunInfo() {
            if (this.currentIndex == this.endIndex) {
                int endIndex = this.endIndex;
                this.currentRunLimit = endIndex;
                this.currentRunStart = endIndex;
                this.currentRunIndex = -1;
            }
            else {
                synchronized (AttributedString.this) {
                    int currentRunIndex;
                    for (currentRunIndex = -1; currentRunIndex < AttributedString.this.runCount - 1 && AttributedString.this.runStarts[currentRunIndex + 1] <= this.currentIndex; ++currentRunIndex) {}
                    if ((this.currentRunIndex = currentRunIndex) >= 0) {
                        this.currentRunStart = AttributedString.this.runStarts[currentRunIndex];
                        if (this.currentRunStart < this.beginIndex) {
                            this.currentRunStart = this.beginIndex;
                        }
                    }
                    else {
                        this.currentRunStart = this.beginIndex;
                    }
                    if (currentRunIndex < AttributedString.this.runCount - 1) {
                        this.currentRunLimit = AttributedString.this.runStarts[currentRunIndex + 1];
                        if (this.currentRunLimit > this.endIndex) {
                            this.currentRunLimit = this.endIndex;
                        }
                    }
                    else {
                        this.currentRunLimit = this.endIndex;
                    }
                }
            }
        }
    }
    
    private final class AttributeMap extends AbstractMap<AttributedCharacterIterator.Attribute, Object>
    {
        int runIndex;
        int beginIndex;
        int endIndex;
        
        AttributeMap(int runIndex, int beginIndex, int endIndex) {
            this.runIndex = runIndex;
            this.beginIndex = beginIndex;
            this.endIndex = endIndex;
        }
        
        @Override
        public Set<Map.Entry<AttributedCharacterIterator.Attribute, Object>> entrySet() {
            HashSet<AttributeEntry> set = new HashSet();
            synchronized (AttributedString.this) {
                for (int size = AttributedString.this.runAttributes[this.runIndex].size(), i = 0; i < size; ++i) {
                    AttributedCharacterIterator.Attribute attribute = (AttributedCharacterIterator.Attribute)AttributedString.this.runAttributes[this.runIndex].get(i);
                    Object o = AttributedString.this.runAttributeValues[this.runIndex].get(i);
                    if ((o instanceof Annotation)) {
                        o = AttributedString.access$400(AttributedString.this, attribute, this.runIndex, this.beginIndex, this.endIndex);
                        if (o == null) {
                            continue;
                        }
                    }
                    set.add(new AttributeEntry(attribute, o));
                }
            }
            return set;
        }
        
        @Override
        public Object get(Object o) {
            return AttributedString.access$400(AttributedString.this, (AttributedCharacterIterator.Attribute)o, this.runIndex, this.beginIndex, this.endIndex);
        }
    }
}
